@@ -561,7 +561,7 @@ class BaseAutoML(BaseEstimator, ABC):
         # If Inputs are not pandas dataframes use scikit-learn validation for X array
         if not isinstance(X, pd.DataFrame):
             # Validate X as array
-            X = check_array(X, ensure_2d=False)
+            X = check_array(X, ensure_2d=False, force_all_finite=False)
             # Force X to be 2D
             X = np.atleast_2d(X)
             # Create Pandas dataframe from np.arrays, columns get names with the schema: feature_{index}
@@ -888,7 +888,7 @@ class BaseAutoML(BaseEstimator, ABC):
                 neg_label, pos_label = 0, 1
             target_is_numeric = self._data_info.get("target_is_numeric", False)
             if target_is_numeric:
-                neg_label = int()
+                neg_label = int(neg_label)
                 pos_label = int(pos_label)
             # assume that it is binary classification
             predictions["label"] = predictions.iloc[:, 1] > self._best_model._threshold
