@@ -1,9 +1,3 @@
-import tempfile
-
-# this set a storage to temp dir
-# you can overwrite this by setting your own dir
-storage_path = tempfile.gettempdir()
-
 import logging
 
 LOG_LEVEL = logging.ERROR
